==> yappari_0.0.31.tar.gz: yappari-0.0.31/src/yappari-application/Gui/changeusernamedialog.h <==
/* Copyright 2012 Naikel Aparicio. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY <COPYRIGHT HOLDER> ''AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL EELI REILIN OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of Eeli Reilin.
 */

#ifndef CHANGEUSERNAMEDIALOG_H
#define CHANGEUSERNAMEDIALOG_H

#include <QDialog>

namespace Ui {
    class ChangeUserNameDialog;
}

class ChangeUserNameDialog : public QDialog
{
    Q_OBJECT

public:
    explicit ChangeUserNameDialog(QWidget *parent = 0);
    ~ChangeUserNameDialog();

    QString getUserName();

private:
    Ui::ChangeUserNameDialog *ui;

protected:
    bool eventFilter(QObject *obj, QEvent *event);

public slots:
    void accept();
};

#endif // CHANGEUSERNAMEDIALOG_H

==> yappari_1.0.37.tar.gz: yappari-1.0.37/src/yappari-application/Gui/changeusernamedialog.h <==
/* Copyright 2012 Naikel Aparicio. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY <COPYRIGHT HOLDER> ''AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL EELI REILIN OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of Eeli Reilin.
 */

#ifndef CHANGEUSERNAMEDIALOG_H
#define CHANGEUSERNAMEDIALOG_H

#include <QDialog>

#include "selectemojiwidget.h"

namespace Ui {
    class ChangeUserNameDialog;
}

class ChangeUserNameDialog : public QDialog
{
    Q_OBJECT

public:
    explicit ChangeUserNameDialog(QWidget *parent = 0);
    ~ChangeUserNameDialog();

    QString getUserName();

private:
    Ui::ChangeUserNameDialog *ui;
    bool isEmojiWidgetOpen;
    SelectEmojiWidget *emojiWidget;
    QWidget *parent;

    void openEmojiWidget();
    void closeEmojiWidget();

protected:
    // bool eventFilter(QObject *obj, QEvent *event);

public slots:
    void accept();
    void selectEmojiButtonClicked();
};

#endif // CHANGEUSERNAMEDIALOG_H
